==> ejc-lz-impl-3.0.0-20220302.022755-3-sources.jar: com/ejianc/business/base/vo/StandardMixVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 标准配比
 * 
 * @author generator
 * 
 */
public class StandardMixVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String name; // 运输商名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long productId; // 产品主键
    private BigDecimal limestoneCoarseAgg; // 石灰岩粗集料
    private BigDecimal limestoneFineAgg; // 石灰岩细集料
    private BigDecimal limestonePacking; // 石灰岩填料
    private BigDecimal wasteFineAgg; // 废石细集料
    private BigDecimal basaltCoarseAgg; // 玄武岩粗集料
    private BigDecimal matrixAsphalt; // 基质沥青
    private BigDecimal modifiedAsphalt; // 改性沥青
    private BigDecimal rubberAsphalt; // 橡胶沥青
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    @ReferSerialTransfer(referCode="idm-user")
    public String getOperatorId() {
        return operatorId;
    }
    @ReferDeserialTransfer
    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public BigDecimal getLimestoneCoarseAgg() {
        return limestoneCoarseAgg;
    }

    public void setLimestoneCoarseAgg(BigDecimal limestoneCoarseAgg) {
        this.limestoneCoarseAgg = limestoneCoarseAgg;
    }
    public BigDecimal getLimestoneFineAgg() {
        return limestoneFineAgg;
    }

    public void setLimestoneFineAgg(BigDecimal limestoneFineAgg) {
        this.limestoneFineAgg = limestoneFineAgg;
    }
    public BigDecimal getLimestonePacking() {
        return limestonePacking;
    }

    public void setLimestonePacking(BigDecimal limestonePacking) {
        this.limestonePacking = limestonePacking;
    }
    public BigDecimal getWasteFineAgg() {
        return wasteFineAgg;
    }

    public void setWasteFineAgg(BigDecimal wasteFineAgg) {
        this.wasteFineAgg = wasteFineAgg;
    }
    public BigDecimal getBasaltCoarseAgg() {
        return basaltCoarseAgg;
    }

    public void setBasaltCoarseAgg(BigDecimal basaltCoarseAgg) {
        this.basaltCoarseAgg = basaltCoarseAgg;
    }
    public BigDecimal getMatrixAsphalt() {
        return matrixAsphalt;
    }

    public void setMatrixAsphalt(BigDecimal matrixAsphalt) {
        this.matrixAsphalt = matrixAsphalt;
    }
    public BigDecimal getModifiedAsphalt() {
        return modifiedAsphalt;
    }

    public void setModifiedAsphalt(BigDecimal modifiedAsphalt) {
        this.modifiedAsphalt = modifiedAsphalt;
    }
    public BigDecimal getRubberAsphalt() {
        return rubberAsphalt;
    }

    public void setRubberAsphalt(BigDecimal rubberAsphalt) {
        this.rubberAsphalt = rubberAsphalt;
    }
    
}

==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/vo/StandardMixVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 标准配比
 * 
 * @author generator
 * 
 */
public class StandardMixVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String name; // 运输商名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private String operatorId; // 经办人id
    private String operatorName; // 经办人名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Long productId; // 产品主键
    private BigDecimal limestoneCoarseAgg; // 石灰岩粗集料
    private BigDecimal limestoneFineAgg; // 石灰岩细集料
    private BigDecimal limestonePacking; // 石灰岩填料
    private BigDecimal wasteFineAgg; // 废石细集料
    private BigDecimal basaltCoarseAgg; // 玄武岩粗集料
    private BigDecimal matrixAsphalt; // 基质沥青
    private BigDecimal modifiedAsphalt; // 改性沥青
    private BigDecimal rubberAsphalt; // 橡胶沥青
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public BigDecimal getLimestoneCoarseAgg() {
        return limestoneCoarseAgg;
    }

    public void setLimestoneCoarseAgg(BigDecimal limestoneCoarseAgg) {
        this.limestoneCoarseAgg = limestoneCoarseAgg;
    }
    public BigDecimal getLimestoneFineAgg() {
        return limestoneFineAgg;
    }

    public void setLimestoneFineAgg(BigDecimal limestoneFineAgg) {
        this.limestoneFineAgg = limestoneFineAgg;
    }
    public BigDecimal getLimestonePacking() {
        return limestonePacking;
    }

    public void setLimestonePacking(BigDecimal limestonePacking) {
        this.limestonePacking = limestonePacking;
    }
    public BigDecimal getWasteFineAgg() {
        return wasteFineAgg;
    }

    public void setWasteFineAgg(BigDecimal wasteFineAgg) {
        this.wasteFineAgg = wasteFineAgg;
    }
    public BigDecimal getBasaltCoarseAgg() {
        return basaltCoarseAgg;
    }

    public void setBasaltCoarseAgg(BigDecimal basaltCoarseAgg) {
        this.basaltCoarseAgg = basaltCoarseAgg;
    }
    public BigDecimal getMatrixAsphalt() {
        return matrixAsphalt;
    }

    public void setMatrixAsphalt(BigDecimal matrixAsphalt) {
        this.matrixAsphalt = matrixAsphalt;
    }
    public BigDecimal getModifiedAsphalt() {
        return modifiedAsphalt;
    }

    public void setModifiedAsphalt(BigDecimal modifiedAsphalt) {
        this.modifiedAsphalt = modifiedAsphalt;
    }
    public BigDecimal getRubberAsphalt() {
        return rubberAsphalt;
    }

    public void setRubberAsphalt(BigDecimal rubberAsphalt) {
        this.rubberAsphalt = rubberAsphalt;
    }
    
}
